==> studio148-prolesapi-1.1.1-27b208.zip: src/Contracts/ProlesApiContract.php <==
<?php

namespace Studio148\ProlesApi\Contracts;

use App\Models\User;
use Illuminate\Support\Collection;
use Studio148\ProlesApi\Exceptions\ProlesApiExceptionHandler;

interface ProlesApiContract
{
    /**
     * @throws ProlesApiExceptionHandler
     */
    public function authenticate(string $username, string $password): mixed;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function authenticateUsingHashedPassword(string $username, string $password): mixed;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function getResetPasswordTemporaryPassword(string $username): string;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function resetPassword($username, $token, $password): object|string;

    /** Get all contact and related data for parents
     * @throws ProlesApiExceptionHandler
     */
    public function getContact(string $email, string $hash): mixed;

    /** Update parent contact data
     * @throws ProlesApiExceptionHandler
     */
    public function updateContact(string $email, string $hash, array $parameters): \stdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function updateChild($email, $hash, $kindId, $kindgegevens): \StdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function updatePaymentInfo(User $user, string $hash): \stdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function getStructureleOpvangDagenForChild(string $email, string $hash, int $kindId): array;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function updateStructureleOpvangDagenForChild($email, $hash, $kindId, $startDate, $newContractDays): array;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function getPresenceForChild(string $email, string $hash, int $kindId): \stdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function updatePresenceForChild($email, $hash, $kindId, $datum): \stdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function getExtraDataForCoordinator(string $email, string $hash): mixed;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function getExtraDataForOverblijfmedewerker(string $email, string $hash): mixed;

    /** Previously named getSchools
     * @throws ProlesApiExceptionHandler
     */
    public function getSchoolsFromProlesApi(): mixed;

    /** Previously named getUsers
     * @throws ProlesApiExceptionHandler
     */
    public function getUsersFromProlesApi(): Collection;
}

==> studio148-prolesapi-1.1.3-31921b.zip: src/Contracts/ProlesApiContract.php <==
<?php

namespace Studio148\ProlesApi\Contracts;

use App\Models\User;
use Illuminate\Contracts\Auth\Authenticatable;
use Illuminate\Support\Collection;
use Studio148\ProlesApi\Exceptions\ProlesApiExceptionHandler;

interface ProlesApiContract
{
    /**
     * @throws ProlesApiExceptionHandler
     */
    public function authenticate(string $username, string $password): mixed;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function authenticateUsingHashedPassword(string $username, string $password): mixed;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function getResetPasswordTemporaryPassword(string $username): string;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function resetPassword($username, $token, $password): object|string;

    /** Get all contact and related data for parents
     * @throws ProlesApiExceptionHandler
     */
    public function getContact(string $email, string $hash): mixed;

    /** Update parent contact data
     * @throws ProlesApiExceptionHandler
     */
    public function updateContact(string $email, string $hash, array $parameters): \stdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function addChildToFamily(Authenticatable $user, \stdClass $child, string $hash): \stdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function updateChild($email, $hash, $kindId, $kindgegevens): \StdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function updatePaymentInfo(Authenticatable $user, string $hash): \stdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function getStructureleOpvangDagenForChild(string $email, string $hash, int $kindId): array;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function updateStructureleOpvangDagenForChild($email, $hash, $kindId, $startDate, $newContractDays): array;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function getPresenceForChild(string $email, string $hash, int $kindId): \stdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function updatePresenceForChild($email, $hash, $kindId, $datum): \stdClass;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function getExtraDataForCoordinator(string $email, string $hash): mixed;

    /**
     * @throws ProlesApiExceptionHandler
     */
    public function getExtraDataForOverblijfmedewerker(string $email, string $hash): mixed;

    /** Previously named getSchools
     * @throws ProlesApiExceptionHandler
     */
    public function getSchoolsFromProlesApi(): mixed;

    /** Previously named getUsers
     * @throws ProlesApiExceptionHandler
     */
    public function getUsersFromProlesApi(): Collection;
}
